OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Добавено към любимите",
    "Removed from favorites" : "Премахни от любимите",
    "You added {file} to your favorites" : "Добавихте {file} към любимите",
    "You removed {file} from your favorites" : "Премахнахте {file} от любимите",
    "Favorites" : "Любими",
    "File changes" : "Файлови промени",
    "Created by {user}" : "Създаден от {user}",
    "Changed by {user}" : "Променен от {user}",
    "Deleted by {user}" : "Изтрит от {user}",
    "Restored by {user}" : "Възстановен от {user}",
    "Renamed by {user}" : "Преименуван от {user}",
    "Moved by {user}" : "Преместен от {user}",
    "\"remote account\"" : "\"профил за отдалечен достъп\"",
    "You created {file}" : "Създадохте {file}",
    "You created an encrypted file in {file}" : "Създадохте криптиран файл в {file}",
    "{user} created {file}" : "{user} създаде {file}",
    "{user} created an encrypted file in {file}" : "{user} създаде криптиран файл в  {file}",
    "{file} was created in a public folder" : "{file} беше създаден в публична папка",
    "You changed {file}" : "Променихте {file}",
    "You changed an encrypted file in {file}" : "Променихте криптиран файл в {file}",
    "{user} changed {file}" : "{user} промени {file}",
    "{user} changed an encrypted file in {file}" : "{user} промени криптиран файл в  {file}",
    "You deleted {file}" : "Изтрихте {file}",
    "You deleted an encrypted file in {file}" : "Изтрихте криптиран файл в {file}",
    "{user} deleted {file}" : "{user} изтри {file}",
    "{user} deleted an encrypted file in {file}" : "{user} изтри криптиран файл в  {file}",
    "You restored {file}" : "Възстановихте {file}",
    "{user} restored {file}" : "{user} възстанови {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Преименувахте {oldfile} (скрит) на {newfile} (скрит)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Преименувахте {oldfile} (скрит) на {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Преименувахте {oldfile} на {newfile} (скрит)",
    "You renamed {oldfile} to {newfile}" : "Преименувахте {oldfile} на {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} преименува {oldfile} (скрит) на {newfile} (скрит)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} преименува {oldfile} (скрит) на {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} преименува {oldfile} на {newfile} (скрит)",
    "{user} renamed {oldfile} to {newfile}" : "{user} преименува {oldfile} на {newfile}",
    "You moved {oldfile} to {newfile}" : "Преместихте {oldfile} в {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} премести {oldfile} в {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Добавяне или премахване на файл от <strong>любимите</strong> ви",
    "Files" : "Файлове",
    "A file or folder has been <strong>changed</strong>" : "<strong>Промяна</strong> на файл / папка",
    "A favorite file or folder has been <strong>changed</strong>" : "Предпочетен файл или папка е <strong>променен</strong>",
    "Failed to authorize" : "Неуспешно оторизиране",
    "Invalid folder path" : "Невалиден път на папката",
    "Folder not found" : "Папката не е намерена",
    "The file cannot be found" : "Файлът не може да бъде намерен",
    "The destination path does not exist: %1$s" : "Пътят на местоназначението не съществува: %1$s",
    "You do not have permission to create a file at the specified location" : "Нямате разрешение да създавате файл на посоченото място",
    "The file could not be converted." : "Файлът не можа да бъде конвертиран.",
    "Could not get relative path to converted file" : "Не можа да се получи свързан път до конвертирания файл",
    "Limit must be a positive integer." : "Лимитът трябва да е положително цяло число.",
    "The replacement character may only be a single character." : "Заместващият символ може да бъде само един символ.",
    "Filename sanitization already started." : "Изчистването на имената на файловете вече е започнато.",
    "No filename sanitization in progress." : "Няма стариран процес за почистване на имена на файлове.",
    "Favorite files" : "Любими файлове",
    "No favorites" : "Няма любими",
    "More favorites" : "Още любими",
    "Accept" : "Приемане",
    "Reject" : "Откажи",
    "Incoming ownership transfer from {user}" : "Входящо прехвърляне на собственост от {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : " Ще приеметели {path}?\n\nЗабележка: Процесът на прехвърляне след приемане може да отнеме до 1 час.",
    "Ownership transfer denied" : "Прехвърлянето на собственост е отказано",
    "Your ownership transfer of {path} was denied by {user}." : "Прехвърлянето на собствеността Ви {path} беше отказано от {user}.",
    "Ownership transfer failed" : "Промяната на собственик е неуспешна",
    "Your ownership transfer of {path} to {user} failed." : "Вашето прехвърляне на собственост на {path} към {user} беше  неуспешно.",
    "The ownership transfer of {path} from {user} failed." : "Прехвърлянето на собственост на {path} към {user} беше  неуспешно.",
    "Ownership transfer done" : "Промяната на собственик е успешна",
    "Your ownership transfer of {path} to {user} has completed." : "Вашето прехвърляне на собственост на {path} към {user} е завършено.",
    "The ownership transfer of {path} from {user} has completed." : "Прехвърлянето на собственост на {path} към {user} е завършено.",
    "in %s" : "в %s",
    "Transferred from %1$s on %2$s" : "Прехвърлено от %1$s на %2$s",
    "File Management" : "Управление на файлове",
    "Home" : "Домашен",
    "Target folder does not exist any more" : "Дестинацията не съществува",
    "Reload current directory" : "Презареждане на текущата директория",
    "Go to the \"{dir}\" directory" : "Отидете в директорията \"{dir}\"",
    "Current directory path" : "Път на текущата директория",
    "Share" : "Споделяне",
    "Your have used your space quota and cannot upload files anymore" : "Използвали сте квотата си за пространство и вече не можете да качвате файлове",
    "You do not have permission to upload or create files here." : "Нямате разрешение да качвате или създавате файлове тук.",
    "Drag and drop files here to upload" : "Плъзнете и пуснете файлове тук, за да ги качите",
    "Favorite" : "Любими",
    "Back" : "Назад",
    "Toggle selection for file \"{displayName}\"" : "Превключване на избора за файл \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Превключване на избора за папка \"{displayName}\"",
    "File is loading" : "Файлът се зарежда",
    "Folder is loading" : "Папката се зарежда",
    "Filename" : "Име на файла",
    "Folder name" : "Име на папка",
    "This node is unavailable" : "Тази точка е недостъпна",
    "Another entry with the same name already exists." : "Вече съществува друг запис със същото име.",
    "Invalid filename." : "Невалидно име на файл.",
    "Rename file" : "Преименуване на файл",
    "Folder" : "Папка",
    "Unknown file type" : "Неизвестен тип файл",
    "{ext} image" : "{ext}изображение",
    "{ext} video" : "{ext}видео",
    "{ext} audio" : "{ext} аудио",
    "{ext} text" : "{ext} текст",
    "Pending" : "Чакащо",
    "Unknown date" : "Неизвестна дата",
    "Active filters" : "Актижни филтри",
    "Remove filter" : "Премахни филтър",
    "Today" : "Днес",
    "Last 7 days" : "Последни 7 дни",
    "Last 30 days" : "Последните 30 дни",
    "This year ({year})" : "Тази година ({year})",
    "Last year ({year})" : "Миналата година ({year})",
    "Search everywhere" : "Търси навсякъде",
    "Documents" : "Документи",
    "Spreadsheets" : "Електронни таблици",
    "Presentations" : "Презентации",
    "PDFs" : "PDF-и",
    "Folders" : "Папки",
    "Audio" : "Аудио",
    "Images" : "Изображения",
    "Videos" : "Видеа",
    "Filters" : "Филтри",
    "Appearance" : "Изглед",
    "Show hidden files" : "Показвай и скрити файлове",
    "Show file type column" : "Показване на колона тип файл",
    "Show file extensions" : "Показване на файлови разширения",
    "Crop image previews" : "Изрязване на визуализациите на изображение",
    "General" : "Общи",
    "Sort favorites first" : "Първо сортирайте любимите",
    "Sort folders before files" : "Сортиране на папки преди файлове",
    "Enable folder tree view" : "Активиране на дървовиден изглед на папки",
    "Default view" : "Изглед по подразбиране",
    "All files" : "Всички файлове",
    "Personal files" : "Лични файлове",
    "Additional settings" : "Допълнителни настройки",
    "Actions" : "Действия",
    "File actions" : "Действия с файлове",
    "Selection" : "Избор",
    "Select all files" : "Изберете всички файлове",
    "Deselect all" : "Откажи всички избрани",
    "Select or deselect" : "Изберете или премахнете отметката",
    "Select a range" : "Изберете обхват",
    "Navigation" : "Навигация",
    "Go to parent folder" : "Отидете до основната папка",
    "Go to file above" : "Отидете до файла по-горе",
    "Go to file below" : "Отидете до файла по-долу",
    "Go left in grid" : "Отидете ляво на мрежата",
    "Go right in grid" : "Отидете дясно на мрежата",
    "View" : "Изглед",
    "Toggle grid view" : "Превключи решетъчния изглед",
    "Show those shortcuts" : "Показване тези преки пътища",
    "Warnings" : "Предупреждения",
    "Warn before changing a file extension" : "Предупреждение преди промяна на файлово разширение",
    "Warn before deleting a file" : "Предупреждение преди изтриване на файл",
    "WebDAV URL" : "WebDAV URL",
    "Create an app password" : "Създайте парола за приложение",
    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Изисква се за WebDAV удостоверяване, тъй като двуфакторното удостоверяване е активирано за този акаунт.",
    "How to access files using WebDAV" : "Как да получите достъп до файлове чрез WebDAV",
    "Total rows summary" : "Обобщение на общия брой редове",
    "Toggle selection for all files and folders" : "Превключване на избора за всички файлове и папки",
    "Name" : "Име",
    "File type" : "Тип файл",
    "Size" : "Размер",
    "Modified" : "Промяна",
    "{displayName}: failed on some elements" : "{displayName}: неуспешно за някои елементи",
    "{displayName}: done" : "{displayName}: готово",
    "{displayName}: failed" : "{displayName}: неуспешно",
    "(selected)" : "(избрано)",
    "List of files and folders." : "Списък с файлове и папки.",
    "You have used your space quota and cannot upload files anymore." : "Използвали сте квотата си за пространство и вече не можете да качвате файлове.",
    "Column headers with buttons are sortable." : "Имената на колоните с бутони имат възможност за сортиране.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Този списък не е изобразен изцяло от съображения за производителност. Файловете ще се изобразяват, докато навигирате в списъка.",
    "File not found" : "Файлът не е намерен",
    "_{count} selected_::_{count} selected_" : ["{count} избрани","{count} избрани"],
    "Search everywhere …" : "Търсете навсякъде...",
    "Search here …" : "Търсете тук...",
    "Search scope options" : "Опции за обхват на търсене",
    "Search here" : "Търсете тук",
    "Owner" : "Създател",
    "{usedQuotaByte} used" : "{usedQuotaByte} използвано",
    "{used} of {quota} used" : "{used} от {quota} използвани",
    "{relative}% used" : "{relative}% използвано",
    "Could not refresh storage stats" : "Статистиката за хранилище не можа да се обнови",
    "Your storage is full, files can not be updated or synced anymore!" : "Хранилището е запълнено. Поради това качването и синхронизирането на файлове е невъзможно!",
    "Storage information" : "Информация за съхранение",
    "Storage quota" : "Квота за съхранение",
    "New folder" : "Нова папка",
    "Create new folder" : "Създай нова папка",
    "This name is already in use." : "Това име вече се използва.",
    "Create" : "Създаване",
    "Files starting with a dot are hidden by default" : "Файловете започващи с точка са скрити по подразбиране",
    "Failed to start filename sanitization." : "Стартирането на почистването на имената на файловете е неуспешно.",
    "Failed to refresh filename sanitization status." : "Неуспешно обновяване на състоянието на почистване на имената на файловете.",
    "Filename sanitization in progress." : "Извършва се почистване на имената на файловете.",
    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "В момента {processedUsers}от {totalUsers} сметките вече са обработени.",
    "Preparing …" : "Подготвя се...",
    "Refresh" : "Опресняване",
    "All files have been santized for Windows filename support." : "Всички файлове са обработени за поддръжка на имена на файлове в Windows.",
    "Some files could not be sanitized, please check your logs." : "Някои файлове не можаха да бъдат почистени, моля, проверете лог файловете си.",
    "Sanitization errors" : "Грешки при почистване",
    "Not sanitized filenames" : "Непочистени имена на файлове",
    "Windows filename support has been enabled." : "Поддръжката на имена на файлове в Windows е активирана.",
    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Въпреки че това блокира потребителите от създаване на нови файлове с неподдържани имена на файлове, съществуващите файлове все още не са преименувани и следователно все още може да прекъсне синхронизацията в Windows.",
    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Можете да задействате преименуване на файлове с невалидни имена на файлове. Това ще се извършва във фонов режим и може да отнеме известно време.",
    "Please note that this may cause high workload on the sync clients." : "Моля, обърнете внимание, че това може да доведе до голямо натоварване на клиентите за синхронизация. ",
    "Limit" : "Ограничение",
    "This allows to configure how many users should be processed in one background job run." : "Това позволява да се конфигурира колко потребители трябва да бъдат обработени в едно фоново изпълнение на задача.",
    "Sanitize filenames" : "Почистване на имената на файловете",
    "(starting)" : "(започва)",
    "Fill template fields" : "Попълнете полетата на шаблона",
    "Submitting fields …" : "Изпращане на полета…",
    "Submit" : "Изпращане",
    "Choose a file or folder to transfer" : "Избор на файл или папка за прехвърляне",
    "Transfer" : "Прехвърли",
    "Transfer {path} to {userid}" : "Прехвърляне на  {path} към {userid}",
    "Invalid path selected" : "Предоставен е невалиден път до файл.",
    "Unknown error" : "Неизвестна грешка",
    "Ownership transfer request sent" : "Изпратена заявка за прехвърляне на собствеността",
    "Cannot transfer ownership of a file or folder you do not own" : "Не можете да прехвърляте собственост върху файл или папка, които не притежавате",
    "Transfer ownership of a file or folder" : "Прехвърляне на собственост на файл или папка",
    "Choose file or folder to transfer" : "Избор на файл или папка за прехвърляне",
    "Change" : "Промени",
    "New owner" : "Нов собственик",
    "Keep {old}" : "Запазете {old}",
    "Keep without extension" : "Съхранявайте без разширение",
    "Use {new}" : "Използвайте {new}",
    "Remove extension" : "Премахване на разширението",
    "Change file extension" : "Променете файловото разширение",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Промяната на файловото разширение от \"{old}\" на \"{new}\" може да направи файла нечетлив",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Премахването на файловото разширение \"{old}\" може да направи файла нечетлив.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Добавянето на файловото разширение \"{new}\" може да направи файла нечетлив.",
    "Do not show this dialog again." : "Не показвай този диалогов прозорец отново.",
    "Cancel" : "Отказ",
    "Rename" : "Преименувай",
    "Select file or folder to link to" : "Избор на файл или папка, към които да поставите връзка",
    "Choose {file}" : "Изберете {file}",
    "Files settings" : "Настройки на файловете",
    "Switch to list view" : "Превключване към изглед на списък",
    "Switch to grid view" : "Превключване към мрежов изглед",
    "The file could not be found" : "Файлът не може да бъде намерен",
    "Upload was cancelled by user" : "Качването е отменено от потребителя",
    "Not enough free space" : "Няма достатъчно свободно място",
    "Operation is blocked by access control" : "Операцията се блокира от контрол на достъпа",
    "Error during upload: {message}" : "Грешка при качване: {message}",
    "Error during upload, status code {status}" : "Грешка при качване, код на състоянието {status}",
    "Unknown error during upload" : "Неизвестна грешка по време на качване",
    "Loading current folder" : "Зареждане на текущата папка",
    "Retry" : "Опитай отново",
    "No files in here" : "Няма файлове",
    "Upload some content or sync with your devices!" : "Качете съдържание или синхронизирайте с вашите устройства!",
    "Go back" : "Назад",
    "Views" : "Изгледи",
    "Your files" : "Вашите файлове",
    "Open in files" : "Отваряне във файлове",
    "File cannot be accessed" : "Файлът не е достъпен",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Файлът не можа да бъде намерен или нямате разрешения да го видите. Помолете подателя да го сподели.",
    "No search results for “{query}”" : "Няма резултати от търсенето на “{query}”",
    "Search for files" : "Търсене на файлове",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Позволява ограничаване на имената на файловете, за да се гарантира, че файловете могат да бъдат синхронизирани с всички клиенти. По подразбиране са разрешени всички имена на файлове, валидни за POSIX (напр. Linux или macOS).",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "След активиране на съвместимите с Windows имена на файлове, съществуващите файлове вече не могат да бъдат променяни, но могат да бъдат преименувани на валидни нови имена от техния собственик.",
    "Failed to toggle Windows filename support" : "Неуспешно превключване на поддръжката за имена на файлове в Windows",
    "Files compatibility" : "Съвместимост на файлове",
    "Enforce Windows compatibility" : "Налагане на съвместимост с Windows",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Това ще блокира имена на файлове, които не са валидни в Windows системи, като например използването на резервирани имена или специални символи. Но това няма да наложи съвместимост с чувствителността към малки и големи букви.",
    "Blank" : "Празен",
    "Unable to create new file from template" : "Не може да се създаде нов файл от шаблон",
    "Pick a template for {name}" : "Избор на шаблон за {name}",
    "Create a new file with the selected template" : "Създаване на нов файл с избрания шаблон",
    "Creating file" : "Създаване на файл ",
    "Save as {displayName}" : "Запиши като {displayName}",
    "Save as …" : "Запиши като...",
    "Converting files …" : "Преобразуване на файлове...",
    "Failed to convert files: {message}" : "Неуспешно конвертиране на файлове: {message}",
    "All files failed to be converted" : "Неуспешно конвертиране на всички файлове",
    "One file could not be converted: {message}" : "Един файл не може да бъде конвертиран: {message}",
    "_%n file could not be converted_::_%n files could not be converted_" : ["%n файл не може да бъде конвертиран","%n файловете не могат да бъдат конвертирани"],
    "_%n file converted_::_%n files converted_" : ["%n преобразуван файл","%nпреобразувани файлове"],
    "Files converted" : "Преобразувани файлове",
    "Failed to convert files" : "Неуспешно конвертиране на файлове",
    "Converting file …" : "Файлът се преобразува...",
    "File successfully converted" : "Файлът е успешно преобразуван",
    "Failed to convert file: {message}" : "Неуспешно конвертиране на файл: {message}",
    "Failed to convert file" : "Неуспешно конвертиране на файла",
    "Delete" : "Изтрий",
    "Leave this share" : "Напускане на споделянето",
    "Leave these shares" : "Разреши споделянето",
    "Disconnect storage" : "Извади хранилището",
    "Disconnect storages" : "Прекъснете съхранението",
    "Delete permanently" : "Изтрий завинаги",
    "Delete and unshare" : "Изтриване и прекратяване на споделянето",
    "Delete file" : "Изтриване на файлове",
    "Delete files" : "Изтриване на файлове",
    "Delete folder" : "Изтриване на папка",
    "Delete folders" : "Изтриване на папки",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["На път сте да изтриете елемента {count} за постоянно","На път сте да изтриете елементите {count} за постоянно"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["На път сте да изтриете {count} елемент","На път сте да изтриете {count} елементи"],
    "Confirm deletion" : "Потвърдете изтриването",
    "Download" : "Изтегли",
    "The requested file is not available." : "Заявеният файл не е наличен.",
    "The requested files are not available." : "Заявените файлове не са налични.",
    "Add to favorites" : "Добави към любимите",
    "Remove from favorites" : "Премахни от любимите",
    "Add or remove favorite" : "Добавете или премахнете любими",
    "Move" : "Преместване",
    "Copy" : "Копирай",
    "Move or copy" : "Премести или копирай",
    "Destination is not a folder" : "Предназначчението не е папка",
    "This file/folder is already in that directory" : "Този файл/папка вече е в тази директория",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Не можете да преместите файл/папка в папка или в подпапка",
    "A file or folder with that name already exists in this folder" : "В тази папка вече съществува файл или папка с това име",
    "The files are locked" : "Файловете са заключени",
    "The file does not exist anymore" : "Файлът вече не съществува",
    "Moving \"{source}\" to \"{destination}\" …" : "Преместване на \"{source}“ към “{destination}\"…",
    "Copying \"{source}\" to \"{destination}\" …" : "Копиране на \"{source}“ в “{destination}\"…",
    "Choose destination" : "Изберете дестинация",
    "Copy to {target}" : "Копиране в {target}",
    "Move to {target}" : "Преместване на {target}",
    "Move or copy operation failed" : "Операцията за преместване или копиране не бе успешна",
    "Open folder" : "Отвори папката",
    "Open folder {displayName}" : "Отворете папка {displayName}",
    "Open in Files" : "Отворете във Файлове",
    "Open locally" : "Локално отваряне",
    "Failed to redirect to client" : "Неуспешно пренасочване към клиент",
    "Open file locally" : "Локално отваряне на файл",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Файлът вече би трябвало да се отвори на вашето устройство. Ако не се отвори, моля, проверете дали имате инсталирано настолното приложение.",
    "Retry and close" : "Опитайте отново и затворете",
    "Open online" : "Отворете онлайн",
    "Details" : "Подробности",
    "View in folder" : "Преглед в папката",
    "Type" : "Тип",
    "Created new folder \"{name}\"" : "Създадена е нова папка “{name}\"",
    "Unable to initialize the templates directory" : "Неуспешно инициализиране на директорията с шаблони",
    "Create templates folder" : "Създаване на папка за шаблони",
    "Templates" : "Шаблони",
    "New template folder" : "Нова папка за шаблони",
    "In folder" : "В папка",
    "Search in all files" : "Търсене във всички файлове",
    "Search in folder: {folder}" : "Търси в папка: {folder}",
    "One of the dropped files could not be processed" : "Един от изтритите файлове не можа да бъде обработен",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Вашият браузър не поддържа Filesystem API. Директориите няма да бъдат качени.",
    "No files to upload" : "Няма файлове за качване",
    "Unable to create the directory {directory}" : "Не може да създадете директорията {directory}",
    "Some files could not be uploaded" : "Някои файлове не можаха да бъдат качени",
    "Files uploaded successfully" : "Файловете са качени успешно",
    "No files to process" : "Няма файлове за обработка",
    "Files copied successfully" : "Файловете са успешно копирани",
    "Files moved successfully" : "Файловете са преместени успешно",
    "Some files could not be copied" : "Някои файлове не можаха да бъдат копирани",
    "Some files could not be moved" : "Някои файлове не могат да бъдат преместени",
    "Conflicts resolution skipped" : "Разрешаването на конфликти е пропуснато",
    "Upload cancelled" : "Качването е отменено",
    "Could not rename \"{oldName}\", it does not exist any more" : "Файлът \"{oldName}\" не може да бъде преименуван защото не съществува",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Името \"{newName}\" се ползва в директорията \"{dir}\". Моля, изберете друго име.",
    "Could not rename \"{oldName}\"" : "\"{oldName}\" не може да бъде преименуван",
    "This operation is forbidden" : "Операцията е забранена",
    "This folder is unavailable, please try again later or contact the administration" : "Тази папка не е налична, моля опитайте отново по-късно или се свържете с администрацията",
    "Storage is temporarily not available" : "Временно хранилището не е налично",
    "Unexpected error: {error}" : "Неочаквана грешка: {error}",
    "_%n file_::_%n files_" : ["%n файл","%n файла"],
    "_%n folder_::_%n folders_" : ["%n папка","%n папки"],
    "_%n hidden_::_%n hidden_" : ["%nскрит","%nскрити"],
    "Filename must not be empty." : "Името на файла не трябва да е празно.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" не е разрешено в името на файла.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" е резервирано име и не е разрешено за имена на файлове.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" не е разрешен файлов тип.",
    "Filenames must not end with \"{extension}\"." : "Имената на файловете не трябва да завършват с \"{extension}\"",
    "List of favorite files and folders." : "Списък с любими файлове и папки.",
    "No favorites yet" : "Няма любими",
    "Files and folders you mark as favorite will show up here" : "Файловете и папките които маркирате като любими ще се показват тук",
    "List of your files and folders." : "Списък с вашите файлове и папки.",
    "Folder tree" : "Дърво на папките",
    "List of your files and folders that are not shared." : "Списък с вашите файлове и папки, които не са споделени.",
    "No personal files found" : "Не са открити лични файлове",
    "Files that are not shared will show up here." : "Файловете, които не са споделени ще се показват тук.",
    "Recent" : "Последни",
    "List of recently modified files and folders." : "Списък с наскоро променени файлове и папки.",
    "No recently modified files" : "Няма наскоро модифицирани файлове",
    "Files and folders you recently modified will show up here." : "Файловете и папките, които наскоро сте променили, ще се покажат тук.",
    "Search" : "Търсене",
    "Search results within your files." : "Резултати от търсенето във вашите файлове.",
    "No entries found in this folder" : "Няма намерени записи в тази папка",
    "Select all" : "Избери всички",
    "Upload too large" : "Прекалено голям файл за качване",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файловете, които се опитвате да качите са по-големи от позволеното на сървъра.",
    "%1$s (renamed)" : "%1$s (преименуван)",
    "renamed file" : "преименуван файл",
    "Upload (max. %s)" : "Качи (макс. %s)",
    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "След активиране на съвместимите с Windows имена на файлове, съществуващите файлове вече не могат да бъдат променяни, но могат да бъдат преименувани на валидни нови имена от техния собственик.",
    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Възможно е също така автоматично мигриране на файлове след активиране на тази настройка. Моля, вижте документацията за командата occ.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Преименуван \"{oldName}\" на \"{newName}\"",
    "Clear filter" : "Изчстиване на филтър",
    "\"{displayName}\" failed on some elements" : "\"{displayName}“ неуспешно при някои елементи",
    "\"{displayName}\" batch action executed successfully" : " Пакетното действие „{displayName}“ е изпълнено успешно",
    "\"{displayName}\" action failed" : "Действието „{displayName}“ е неуспешно",
    "Submitting fields …" : "Изпращане на полета...",
    "Shared by link" : "Споделени с връзка",
    "Shared" : "Споделен",
    "\"{displayName}\" action executed successfully" : "Действието „{displayName}“ е изпълнено успешно",
    "Filter file names …" : "Филтриране на имена на файлове...",
    "Clipboard is not available" : "Клипбордът не е достъпен",
    "WebDAV URL copied to clipboard" : "WebDAV URL адрес е копиран в клипборда",
    "Enable the grid view" : "Активирайте мрежовия изглед",
    "Enable folder tree" : "Активиране на дървото на папките",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Копиране в клипборда",
    "Use this address to access your Files via WebDAV" : "Ползвайте този адрес за достъп до файловете си чрез WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Ако сте активирали 2FA, трябва да създадете и използвате нова парола за приложението, като кликнете тук.",
    "Prevent warning dialogs from open or reenable them." : "Предотвратете отварянето на предупредителни диалози или ги активирайте отново.",
    "Show a warning dialog when changing a file extension." : "Показване на диалогов прозорец за предупреждение при промяна на файлово разширение.",
    "Keyboard shortcuts" : "Бързи клавиши",
    "Speed up your Files experience with these quick shortcuts." : "Ускорете работата си с Файлове с тези бързи клавишни комбинации.",
    "Open the actions menu for a file" : "Отваряне на менюто с действия за файл",
    "Rename a file" : "Преименуване на файл",
    "Delete a file" : "Изтриване на файл",
    "Favorite or remove a file from favorites" : "Добавяне към любими или премахване на файл от любими ",
    "Manage tags for a file" : "Управление на етикети за файл",
    "Deselect all files" : "Демаркирайте всички файлове",
    "Select or deselect a file" : "Избиране или премахване на избора на файл",
    "Select a range of files" : "Изберете диапазон от файлове",
    "Navigate to the parent folder" : "Навигиране до основната папка",
    "Navigate to the file above" : "Отидете до файла по-горе",
    "Navigate to the file below" : "Отидете до файла по-долу",
    "Navigate to the file on the left (in grid mode)" : "Придвижете се до файла отляво (в режим на мрежа)",
    "Navigate to the file on the right (in grid mode)" : "Придвижете се до файла отдясно (в режим на мрежа)",
    "Toggle the grid view" : "Превключване на мрежовия изглед",
    "Open the sidebar for a file" : "Отваряне на страничната лента за файл",
    "You" : "Вие",
    "Shared multiple times with different people" : "Споделяно многократно с различни хора",
    "Unable to change the favorite state of the file" : "Не може да се промени любимото състояние на файла",
    "Error while loading the file data" : "Грешка при зареждането на файловете.",
    "Tags" : "Етикети",
    "Save as …" : "Запази като...",
    "Converting files …" : "Конвертиране на файлове...",
    "Converting file …" : "Файлът се преобразува...",
    "Deletion cancelled" : "Изтриването е отменено",
    "Edit locally" : "Локално редактиране",
    "Moving \"{source}\" to \"{destination}\" …" : "Преместване на \"{source}\" към \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Копиране на \"{source}\" в \"{destination}\" …",
    "(copy)" : "(копие)",
    "(copy %n)" : "(копирай %n)",
    "Move cancelled" : "Преместването е отменено",
    "Cancelled move or copy of \"{filename}\"." : "Преместването или копирането на \"{filename}\" е отменено.",
    "Cancelled move or copy operation" : "Операцията за преместване или копиране е отменена",
    "Open details" : "Отваряне на подробности",
    "Photos and images" : "Снимки и изображения",
    "New folder creation cancelled" : "Създаването на нова папка е отменено",
    "This directory is unavailable, please check the logs or contact the administrator" : "Директорията не е налична. Проверете журнала или се свържете с администратора",
    "All folders" : "Всички папки",
    "Open file sidebar" : "Отворете страничната лента на файла",
    "Search everywhere …" : "Търсете навсякъде...",
    "Search here …" : "Търсете тук...",
    "Preparing …" : "Подготвя се..."
},
"nplurals=2; plural=(n != 1);");
